@@ -1,6 +1,6 @@
 /***********************************************************************
  *
- * Copyright (C) 2009, 2010, 2011, 2012 Graeme Gott <graeme@gottcode.org>
+ * Copyright (C) 2009, 2010, 2011, 2012, 2014 Graeme Gott <graeme@gottcode.org>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -57,6 +57,7 @@ public:
 	int pageCount() const;
 	int paragraphCount() const;
 	int wordCount() const;
+	int wordCountDelta() const;
 	SceneModel* sceneModel() const;
 	QTextEdit* text() const;
 
@@ -65,6 +66,7 @@ public:
 	bool saveAs();
 	bool rename();
 	void reload(bool prompt = true);
+	void close();
 	void checkSpelling();
 	void print();
 	bool loadFile(const QString& filename, int position);
@@ -155,6 +157,7 @@ private:
 	Stats m_cached_stats;
 	int m_cached_block_count;
 	int m_cached_current_block;
+	int m_saved_wordcount;
 
 	int m_page_type;
 	float m_page_amount;
@@ -205,6 +208,10 @@ inline int Document::wordCount() const {
 	return m_stats->wordCount();
 }
 
+inline int Document::wordCountDelta() const {
+	return m_document_stats.wordCount() - m_saved_wordcount;
+}
+
 inline SceneModel* Document::sceneModel() const {
 	return m_scene_model;
 }
