@@ -1,6 +1,6 @@
 /***********************************************************************
  *
- * Copyright (C) 2008, 2009, 2010, 2011, 2012 Graeme Gott <graeme@gottcode.org>
+ * Copyright (C) 2008, 2009, 2010, 2011, 2012, 2014 Graeme Gott <graeme@gottcode.org>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -226,7 +226,7 @@ void FindDialog::replaceAll()
 	if (!m_ignore_case->isChecked()) {
 		flags |= QTextDocument::FindCaseSensitively;
 	}
-	if (m_whole_words->isChecked()) {
+	if (m_whole_words->isChecked() && !m_regular_expressions->isChecked()) {
 		flags |= QTextDocument::FindWholeWords;
 	}
 
@@ -247,7 +247,7 @@ void FindDialog::replaceAll()
 	} else {
 		forever {
 			cursor = document->document()->find(regex, cursor, flags);
-			if (!cursor.isNull()) {
+			if (!cursor.isNull() && cursor.hasSelection()) {
 				found++;
 			} else {
 				break;
@@ -279,7 +279,7 @@ void FindDialog::replaceAll()
 	} else {
 		forever {
 			cursor = document->document()->find(regex, cursor, flags);
-			if (!cursor.isNull()) {
+			if (!cursor.isNull() && cursor.hasSelection()) {
 				QString match = cursor.selectedText();
 				match.replace(regex, m_replace_string->text());
 				cursor.insertText(match);
@@ -307,7 +307,7 @@ void FindDialog::find(bool backwards)
 	if (!m_ignore_case->isChecked()) {
 		flags |= QTextDocument::FindCaseSensitively;
 	}
-	if (m_whole_words->isChecked()) {
+	if (m_whole_words->isChecked() && !m_regular_expressions->isChecked()) {
 		flags |= QTextDocument::FindWholeWords;
 	}
 	if (backwards) {
