@@ -1,6 +1,6 @@
 /***********************************************************************
  *
- * Copyright (C) 2008, 2009, 2010, 2011, 2012 Graeme Gott <graeme@gottcode.org>
+ * Copyright (C) 2008, 2009, 2010, 2011, 2012, 2014 Graeme Gott <graeme@gottcode.org>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -194,8 +194,5 @@ int main(int argc, char** argv)
 		return 0;
 	}
 
-	// Browse to documents after command-line specified documents have been loaded
-	QDir::setCurrent(QSettings().value("Save/Location", QDir::homePath()).toString());
-
 	return app.exec();
 }
