@@ -1,6 +1,6 @@
 /***********************************************************************
  *
- * Copyright (C) 2012 Graeme Gott <graeme@gottcode.org>
+ * Copyright (C) 2012, 2014 Graeme Gott <graeme@gottcode.org>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -91,7 +91,7 @@ void SymbolsDialog::ElideLabel::paintEvent(QPaintEvent* event)
 //-----------------------------------------------------------------------------
 
 SymbolsDialog::SymbolsDialog(QWidget* parent) :
-	QDialog(parent)
+	QDialog(parent, Qt::WindowTitleHint | Qt::WindowSystemMenuHint | Qt::WindowCloseButtonHint)
 {
 	setWindowTitle(tr("Symbols"));
 
