@@ -1,6 +1,6 @@
 /***********************************************************************
  *
- * Copyright (C) 2009, 2010, 2011, 2012 Graeme Gott <graeme@gottcode.org>
+ * Copyright (C) 2009, 2010, 2011, 2012, 2013 Graeme Gott <graeme@gottcode.org>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 #include "theme_dialog.h"
 
 #include "color_button.h"
+#include "font_combobox.h"
 #include "image_button.h"
 #include "theme.h"
 
@@ -30,7 +31,6 @@
 #include <QDialogButtonBox>
 #include <QDoubleValidator>
 #include <QFile>
-#include <QFontComboBox>
 #include <QFormLayout>
 #include <QGroupBox>
 #include <QLabel>
@@ -134,7 +134,7 @@ ThemeDialog::ThemeDialog(Theme& theme, QWidget* parent)
 	m_foreground_margin = new QSpinBox(tab);
 	m_foreground_margin->setCorrectionMode(QSpinBox::CorrectToNearestValue);
 	m_foreground_margin->setSuffix(tr(" pixels"));
-	m_foreground_margin->setRange(10, 250);
+	m_foreground_margin->setRange(1, 250);
 	m_foreground_margin->setValue(m_theme.foregroundMargin());
 
 	m_foreground_padding = new QSpinBox(tab);
@@ -173,7 +173,7 @@ ThemeDialog::ThemeDialog(Theme& theme, QWidget* parent)
 	m_text_color->setColor(m_theme.textColor());
 	connect(m_text_color, SIGNAL(changed(QColor)), this, SLOT(renderPreview()));
 
-	m_font_names = new QFontComboBox(tab);
+	m_font_names = new FontComboBox(tab);
 	m_font_names->setEditable(false);
 	m_font_names->setCurrentFont(m_theme.textFont());
 	connect(m_font_names, SIGNAL(activated(int)), this, SLOT(fontChanged()));
@@ -260,7 +260,7 @@ ThemeDialog::ThemeDialog(Theme& theme, QWidget* parent)
 	spacing_layout->addWidget(paragraph_spacing);
 	spacing_layout->addStretch();
 
-#if QT_VERSION < 0x040800
+#if (QT_VERSION < QT_VERSION_CHECK(4,8,0))
 	line_spacing->hide();
 #endif
 
