@@ -1,6 +1,6 @@
 /***********************************************************************
  *
- * Copyright (C) 2008, 2009, 2010, 2011, 2012, 2013 Graeme Gott <graeme@gottcode.org>
+ * Copyright (C) 2008, 2009, 2010, 2011, 2012, 2013, 2014 Graeme Gott <graeme@gottcode.org>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -409,12 +409,10 @@ void Window::addDocuments(const QStringList& files, const QStringList& datafiles
 
 	// Skip loading files of unsupported formats
 	static const QStringList suffixes = QStringList()
-		<< "abw" << "awt" << "zabw"
-		<< "doc" << "dot"
-		<< "docx" << "docm" << "dotx" << "dotm"
-		<< "kwd"
-		<< "ott"
-		<< "wpd";
+		<< "abw" << "awt" << "zabw" << "doc" << "dot" << "docx" << "docm" << "dotx" << "dotm" << "kwd" << "ott" << "wpd"
+		<< "bmp" << "dds" << "gif" << "icns" << "ico" << "jng" << "jp2" << "jpg" << "jpeg" << "jps" << "mng" << "png" << "tga" << "tif" << "tiff" << "xcf"
+		<< "aac" << "aif" << "aifc" << "aiff" << "asf" << "au" << "flac" << "mid" << "midi" << "mod" << "mp2" << "mp3" << "m4a" << "ogg" << "s3m" << "snd" << "spx" << "wav" << "wma"
+		<< "avi" << "m1v" << "m2ts" << "m4v" << "mkv" << "mov" << "mp4" << "mp4v" << "mpa" << "mpe" << "mpg" << "mpeg" << "mpv2" << "wm" << "wmv";
 	QList<int> skip;
 	for (int i = 0; i < files.count(); ++i) {
 		if (suffixes.contains(QFileInfo(files.at(i)).suffix().toLower())) {
@@ -441,7 +439,7 @@ void Window::addDocuments(const QStringList& files, const QStringList& datafiles
 	int current_index = -1;
 	if (m_documents->count()) {
 		current_index = m_documents->currentIndex();
-		Document* document = m_documents->count() ? m_documents->currentDocument() : 0;
+		Document* document = m_documents->currentDocument();
 		if (document->untitledIndex() && !document->text()->document()->isModified()) {
 			untitled_index = m_documents->currentIndex();
 		}
@@ -449,6 +447,7 @@ void Window::addDocuments(const QStringList& files, const QStringList& datafiles
 
 	// Read files
 	QStringList missing;
+	QStringList errors;
 	QStringList readonly;
 	int open_files = m_documents->count();
 	for (int i = 0; i < files.count(); ++i) {
@@ -463,7 +462,7 @@ void Window::addDocuments(const QStringList& files, const QStringList& datafiles
 		} else if (!files.at(i).isEmpty() && (m_documents->currentDocument()->untitledIndex() > 0)) {
 			// Track if unable to read file
 			int index = m_documents->currentIndex();
-			missing.append(QDir::toNativeSeparators(files.at(i)));
+			errors.append(QDir::toNativeSeparators(files.at(i)));
 			m_documents->removeDocument(index);
 			m_tabs->removeTab(index);
 		} else if (m_documents->currentDocument()->isReadOnly() && (m_documents->count() > open_files)) {
@@ -485,8 +484,8 @@ void Window::addDocuments(const QStringList& files, const QStringList& datafiles
 		} else if (m_documents->currentIndex() == current_index) {
 			m_tabs->setCurrentIndex(m_tabs->count() - 1);
 		}
-	} else {
-		// Replace current tab if it is untitled and unmodified
+	// Replace current tab if it is untitled and unmodified
+	} else if (files.count() > (missing.count() + errors.count())) {
 		m_tabs->setCurrentIndex(untitled_index);
 		closeDocument();
 	}
@@ -737,11 +736,11 @@ void Window::closeDocument()
 		return;
 	}
 
-	if (m_documents->count() == 1) {
-		newDocument();
-	}
 	m_documents->removeDocument(index);
 	m_tabs->removeTab(index);
+	if (m_documents->count() == 0) {
+		newDocument();
+	}
 }
 
 //-----------------------------------------------------------------------------
@@ -759,11 +758,11 @@ void Window::closeDocument(Document* document)
 		return;
 	}
 
-	if (m_documents->count() == 1) {
-		newDocument();
-	}
 	m_documents->removeDocument(index);
 	m_tabs->removeTab(index);
+	if (m_documents->count() == 0) {
+		newDocument();
+	}
 }
 
 //-----------------------------------------------------------------------------
@@ -1150,6 +1149,7 @@ bool Window::saveDocument(int index)
 		return document->save();
 	case QMessageBox::Discard:
 		document->text()->document()->setModified(false);
+		m_current_wordcount -= document->wordCountDelta();
 		return true;
 	case QMessageBox::Cancel:
 	default:
