@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="zh_CN" sourcelanguage="en">
+<TS version="2.1" language="zh_CN" sourcelanguage="en">
 <context>
     <name>Alert</name>
     <message>
@@ -35,86 +35,86 @@
 <context>
     <name>Document</name>
     <message>
-        <location filename="../src/document.cpp" line="348"/>
-        <location filename="../src/document.cpp" line="368"/>
-        <location filename="../src/document.cpp" line="399"/>
-        <location filename="../src/document.cpp" line="405"/>
+        <location filename="../src/document.cpp" line="358"/>
+        <location filename="../src/document.cpp" line="383"/>
+        <location filename="../src/document.cpp" line="414"/>
+        <location filename="../src/document.cpp" line="420"/>
         <source>Sorry</source>
-        <translation>Sorry</translation>
+        <translation>抱歉</translation>
     </message>
     <message>
-        <location filename="../src/document.cpp" line="348"/>
+        <location filename="../src/document.cpp" line="358"/>
         <source>Unable to save &apos;%1&apos;.</source>
         <translation>不能保存 &apos;%1&apos;。</translation>
     </message>
     <message>
-        <location filename="../src/document.cpp" line="361"/>
+        <location filename="../src/document.cpp" line="373"/>
         <source>Save File As</source>
         <translation>保存文件为</translation>
     </message>
     <message>
-        <location filename="../src/document.cpp" line="368"/>
-        <location filename="../src/document.cpp" line="399"/>
+        <location filename="../src/document.cpp" line="383"/>
+        <location filename="../src/document.cpp" line="414"/>
         <source>Unable to overwrite &apos;%1&apos;.</source>
         <translation>不能覆盖 &apos;%1&apos;。</translation>
     </message>
     <message>
-        <location filename="../src/document.cpp" line="392"/>
+        <location filename="../src/document.cpp" line="407"/>
         <source>Rename File</source>
         <translation>重命名文件</translation>
     </message>
     <message>
-        <location filename="../src/document.cpp" line="405"/>
+        <location filename="../src/document.cpp" line="420"/>
         <source>Unable to rename &apos;%1&apos;.</source>
         <translation>不能重命名 &apos;%1&apos;。</translation>
     </message>
     <message>
-        <location filename="../src/document.cpp" line="430"/>
+        <location filename="../src/document.cpp" line="445"/>
         <source>Reload File</source>
         <translation>重新加载文件</translation>
     </message>
     <message>
-        <location filename="../src/document.cpp" line="431"/>
+        <location filename="../src/document.cpp" line="446"/>
         <source>Reload the file %1 from disk?</source>
         <translation>重新从磁盘中加载文件 %1 ？</translation>
     </message>
     <message>
-        <location filename="../src/document.cpp" line="432"/>
+        <location filename="../src/document.cpp" line="447"/>
         <source>All unsaved changes will be lost.</source>
         <translation>未保存的更改将丢失。</translation>
     </message>
     <message>
-        <location filename="../src/document.cpp" line="434"/>
+        <location filename="../src/document.cpp" line="449"/>
         <source>Reload</source>
         <translation>重新加载</translation>
     </message>
     <message>
-        <location filename="../src/document.cpp" line="1168"/>
+        <location filename="../src/document.cpp" line="1198"/>
         <source>Plain Text (*.txt)</source>
         <translation>纯文本 (*.txt)</translation>
     </message>
     <message>
-        <location filename="../src/document.cpp" line="1227"/>
+        <location filename="../src/document.cpp" line="1257"/>
         <source>Question</source>
         <translation>问题</translation>
     </message>
     <message>
-        <location filename="../src/document.cpp" line="1228"/>
+        <location filename="../src/document.cpp" line="1258"/>
         <source>Saving as plain text will discard all formatting. Discard formatting?</source>
         <translation>保存为纯文本将丢弃全部格式。丢弃格式吗？</translation>
     </message>
     <message>
-        <location filename="../src/document.cpp" line="1166"/>
+        <location filename="../src/document.cpp" line="1196"/>
         <source>OpenDocument Text (*.odt)</source>
         <translation>OpenDocument Text (*.odt)</translation>
     </message>
     <message>
-        <location filename="../src/document.cpp" line="1167"/>
+        <location filename="../src/document.cpp" line="1197"/>
         <source>Rich Text (*.rtf)</source>
-        <translation>Rich Text (*.rtf)</translation>
+        <translation>多信息文本格式 (*.rtf)</translation>
     </message>
     <message>
-        <location filename="../src/document.cpp" line="1169"/>
+        <location filename="../src/document.cpp" line="1199"/>
         <source>All Files (*)</source>
         <translation>所有文件 (*)</translation>
     </message>
@@ -227,8 +227,8 @@
     <message numerus="yes">
         <location filename="../src/find_dialog.cpp" line="258"/>
         <source>Replace %n instance(s)?</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
+        <translation>
+            <numerusform>替换 %n 个实例？</numerusform>
         </translation>
     </message>
     <message>
@@ -240,7 +240,7 @@
         <location filename="../src/find_dialog.cpp" line="262"/>
         <location filename="../src/find_dialog.cpp" line="337"/>
         <source>Sorry</source>
-        <translation>Sorry</translation>
+        <translation>抱歉</translation>
     </message>
     <message>
         <location filename="../src/find_dialog.cpp" line="262"/>
@@ -252,17 +252,17 @@
 <context>
     <name>Highlighter</name>
     <message>
-        <location filename="../src/highlighter.cpp" line="51"/>
+        <location filename="../src/highlighter.cpp" line="52"/>
         <source>Add</source>
         <translation>添加</translation>
     </message>
     <message>
-        <location filename="../src/highlighter.cpp" line="52"/>
+        <location filename="../src/highlighter.cpp" line="53"/>
         <source>Check Spelling...</source>
         <translation>检查拼写...</translation>
     </message>
     <message>
-        <location filename="../src/highlighter.cpp" line="124"/>
+        <location filename="../src/highlighter.cpp" line="127"/>
         <source>(No suggestions found)</source>
         <translation>（找不到建议）</translation>
     </message>
@@ -290,7 +290,7 @@
     <message>
         <location filename="../src/locale_dialog.cpp" line="53"/>
         <source>&lt;System Language&gt;</source>
-        <translation>&lt;System Language&gt;</translation>
+        <translation>&lt;系统语言&gt;</translation>
     </message>
     <message>
         <location filename="../src/locale_dialog.cpp" line="183"/>
@@ -308,12 +308,12 @@
     <message>
         <location filename="../src/preferences_dialog.cpp" line="109"/>
         <source>Preferences</source>
-        <translation>偏好设置</translation>
+        <translation>首选项</translation>
     </message>
     <message>
         <location filename="../src/preferences_dialog.cpp" line="112"/>
         <source>General</source>
-        <translation>一般</translation>
+        <translation>常规</translation>
     </message>
     <message>
         <location filename="../src/preferences_dialog.cpp" line="113"/>
@@ -339,7 +339,7 @@
         <location filename="../src/preferences_dialog.cpp" line="420"/>
         <location filename="../src/preferences_dialog.cpp" line="541"/>
         <source>Sorry</source>
-        <translation>Sorry</translation>
+        <translation>抱歉</translation>
     </message>
     <message>
         <location filename="../src/preferences_dialog.cpp" line="420"/>
@@ -421,7 +421,7 @@
     <message>
         <location filename="../src/preferences_dialog.cpp" line="713"/>
         <source>Block insertion cursor</source>
-        <translation>块插入光标</translation>
+        <translation>块状光标</translation>
     </message>
     <message>
         <location filename="../src/preferences_dialog.cpp" line="714"/>
@@ -441,22 +441,22 @@
     <message>
         <location filename="../src/preferences_dialog.cpp" line="724"/>
         <source>Double</source>
-        <translation>双引号</translation>
+        <translation>双倍行距</translation>
     </message>
     <message>
         <location filename="../src/preferences_dialog.cpp" line="725"/>
         <source>Single</source>
-        <translation>单引号</translation>
+        <translation>单线</translation>
     </message>
     <message>
         <location filename="../src/preferences_dialog.cpp" line="746"/>
         <source>Scenes</source>
-        <translation type="unfinished"></translation>
+        <translation>场景</translation>
     </message>
     <message>
         <location filename="../src/preferences_dialog.cpp" line="753"/>
         <source>Divider:</source>
-        <translation type="unfinished"></translation>
+        <translation>分隔符:</translation>
     </message>
     <message>
         <location filename="../src/preferences_dialog.cpp" line="756"/>
@@ -633,8 +633,8 @@
 <context>
     <name>Reader</name>
     <message>
-        <location filename="../src/rtf/reader.cpp" line="225"/>
-        <location filename="../src/rtf/reader.cpp" line="229"/>
+        <location filename="../src/rtf/reader.cpp" line="226"/>
+        <location filename="../src/rtf/reader.cpp" line="230"/>
         <source>Not a supported RTF file.</source>
         <translation>不支持的RTF文件。</translation>
     </message>
@@ -664,7 +664,7 @@
     <message>
         <location filename="../src/scene_list.cpp" line="94"/>
         <source>Move Scenes Up</source>
-        <translation type="unfinished"></translation>
+        <translation>向上移动场景</translation>
     </message>
     <message>
         <location filename="../src/scene_list.cpp" line="95"/>
@@ -674,7 +674,7 @@
     <message>
         <location filename="../src/scene_list.cpp" line="115"/>
         <source>Toggle Scene List</source>
-        <translation type="unfinished"></translation>
+        <translation>打开/关闭场景列表</translation>
     </message>
     <message>
         <location filename="../src/scene_list.cpp" line="116"/>
@@ -684,12 +684,12 @@
     <message>
         <location filename="../src/scene_list.cpp" line="399"/>
         <source>Show scene list (%1)</source>
-        <translation type="unfinished"></translation>
+        <translation>显示场景列表(%1)</translation>
     </message>
     <message>
         <location filename="../src/scene_list.cpp" line="400"/>
         <source>Hide scene list (%1)</source>
-        <translation type="unfinished"></translation>
+        <translation>隐藏场景列表(%1)</translation>
     </message>
     <message>
         <location filename="../src/scene_list.cpp" line="147"/>
@@ -699,12 +699,12 @@
     <message>
         <location filename="../src/scene_list.cpp" line="88"/>
         <source>Move Scenes Down</source>
-        <translation type="unfinished"></translation>
+        <translation>向下移动场景</translation>
     </message>
     <message>
         <location filename="../src/scene_list.cpp" line="155"/>
         <source>Resize scene list</source>
-        <translation type="unfinished"></translation>
+        <translation>调整场景列表大小</translation>
     </message>
 </context>
 <context>
@@ -713,10 +713,11 @@
         <location filename="../src/main.cpp" line="173"/>
         <location filename="../src/session.cpp" line="35"/>
         <location filename="../src/session.cpp" line="42"/>
-        <location filename="../src/session_manager.cpp" line="147"/>
-        <location filename="../src/session_manager.cpp" line="359"/>
-        <location filename="../src/session_manager.cpp" line="376"/>
-        <location filename="../src/session_manager.cpp" line="379"/>
+        <location filename="../src/session_manager.cpp" line="148"/>
+        <location filename="../src/session_manager.cpp" line="360"/>
+        <location filename="../src/session_manager.cpp" line="377"/>
+        <location filename="../src/session_manager.cpp" line="380"/>
+        <location filename="../src/theme_manager.cpp" line="193"/>
         <source>Default</source>
         <translation>默认</translation>
     </message>
@@ -759,62 +760,62 @@
         <translation>切换到</translation>
     </message>
     <message>
-        <location filename="../src/session_manager.cpp" line="170"/>
+        <location filename="../src/session_manager.cpp" line="171"/>
         <source>New Session</source>
         <translation>新会话</translation>
     </message>
     <message>
-        <location filename="../src/session_manager.cpp" line="216"/>
+        <location filename="../src/session_manager.cpp" line="217"/>
         <source>Clone Session</source>
         <translation>克隆会话</translation>
     </message>
     <message>
-        <location filename="../src/session_manager.cpp" line="256"/>
+        <location filename="../src/session_manager.cpp" line="257"/>
         <source>Rename Session</source>
         <translation>重命名会话</translation>
     </message>
     <message>
-        <location filename="../src/session_manager.cpp" line="283"/>
+        <location filename="../src/session_manager.cpp" line="284"/>
         <source>Question</source>
         <translation>询问</translation>
     </message>
     <message>
-        <location filename="../src/session_manager.cpp" line="283"/>
+        <location filename="../src/session_manager.cpp" line="284"/>
         <source>Delete selected session?</source>
         <translation>删除所选会话？</translation>
     </message>
     <message>
-        <location filename="../src/session_manager.cpp" line="354"/>
+        <location filename="../src/session_manager.cpp" line="355"/>
         <source>Session name:</source>
         <translation>会话名称：</translation>
     </message>
     <message>
-        <location filename="../src/session_manager.cpp" line="362"/>
+        <location filename="../src/session_manager.cpp" line="363"/>
         <source>Sorry</source>
-        <translation>Sorry</translation>
+        <translation>抱歉</translation>
     </message>
     <message>
-        <location filename="../src/session_manager.cpp" line="362"/>
+        <location filename="../src/session_manager.cpp" line="363"/>
         <source>The requested session name is already in use.</source>
         <translation>请求的会话名称已在使用中。</translation>
     </message>
     <message>
-        <location filename="../src/session_manager.cpp" line="402"/>
+        <location filename="../src/session_manager.cpp" line="403"/>
         <source>&amp;New...</source>
         <translation>新建(&amp;N)...</translation>
     </message>
     <message>
-        <location filename="../src/session_manager.cpp" line="402"/>
+        <location filename="../src/session_manager.cpp" line="403"/>
         <source>Ctrl+Shift+N</source>
         <translation>Ctrl+Shift+N</translation>
     </message>
     <message>
-        <location filename="../src/session_manager.cpp" line="403"/>
+        <location filename="../src/session_manager.cpp" line="404"/>
         <source>&amp;Manage...</source>
         <translation>管理(&amp;M)...</translation>
     </message>
     <message>
-        <location filename="../src/session_manager.cpp" line="403"/>
+        <location filename="../src/session_manager.cpp" line="404"/>
         <source>Ctrl+Shift+M</source>
         <translation>Ctrl+Shift+M</translation>
     </message>
@@ -871,7 +872,7 @@
     <message>
         <location filename="../src/spell_checker.cpp" line="144"/>
         <source>I&amp;gnore All</source>
-        <translation>忽略全部(&amp;G)</translation>
+        <translation>忽略全部(&amp;g)</translation>
     </message>
     <message>
         <location filename="../src/spell_checker.cpp" line="149"/>
@@ -881,7 +882,7 @@
     <message>
         <location filename="../src/spell_checker.cpp" line="152"/>
         <source>C&amp;hange All</source>
-        <translation>更改全部(&amp;H)</translation>
+        <translation>更改全部(&amp;h)</translation>
     </message>
     <message>
         <location filename="../src/spell_checker.cpp" line="167"/>
@@ -939,12 +940,12 @@
     <message>
         <location filename="../src/symbols_dialog.cpp" line="221"/>
         <source>Name:</source>
-        <translation type="unfinished">名称：</translation>
+        <translation>名称：</translation>
     </message>
     <message>
         <location filename="../src/symbols_dialog.cpp" line="231"/>
         <source>Insert</source>
-        <translation type="unfinished"></translation>
+        <translation>插入</translation>
     </message>
 </context>
 <context>
@@ -952,12 +953,12 @@
     <message>
         <location filename="../src/symbols_model.cpp" line="107"/>
         <source>Blocks</source>
-        <translation type="unfinished"></translation>
+        <translation>块</translation>
     </message>
     <message>
         <location filename="../src/symbols_model.cpp" line="107"/>
         <source>Scripts</source>
-        <translation type="unfinished"></translation>
+        <translation>文字</translation>
     </message>
 </context>
 <context>
@@ -1110,52 +1111,52 @@
     <message>
         <location filename="../src/theme_dialog.cpp" line="207"/>
         <source>Spacings</source>
-        <translation type="unfinished"></translation>
+        <translation>间隔</translation>
     </message>
     <message>
         <location filename="../src/theme_dialog.cpp" line="209"/>
         <source>Line Spacing</source>
-        <translation type="unfinished"></translation>
+        <translation>行距</translation>
     </message>
     <message>
         <location filename="../src/theme_dialog.cpp" line="213"/>
         <source>Single</source>
-        <translation type="unfinished">单引号</translation>
+        <translation>单线</translation>
     </message>
     <message>
         <location filename="../src/theme_dialog.cpp" line="213"/>
         <source>1.5 Lines</source>
-        <translation type="unfinished"></translation>
+        <translation>1.5 倍行距</translation>
     </message>
     <message>
         <location filename="../src/theme_dialog.cpp" line="213"/>
         <source>Double</source>
-        <translation type="unfinished">双引号</translation>
+        <translation>双倍行距</translation>
     </message>
     <message>
         <location filename="../src/theme_dialog.cpp" line="213"/>
         <source>Proportional</source>
-        <translation type="unfinished"></translation>
+        <translation>成比例</translation>
     </message>
     <message>
         <location filename="../src/theme_dialog.cpp" line="232"/>
         <source>Paragraph Spacing</source>
-        <translation type="unfinished"></translation>
+        <translation>段间距</translation>
     </message>
     <message>
         <location filename="../src/theme_dialog.cpp" line="254"/>
         <source>Indent First Line:</source>
-        <translation type="unfinished"></translation>
+        <translation>首行缩进:</translation>
     </message>
     <message>
         <location filename="../src/theme_dialog.cpp" line="255"/>
         <source>Pixels Above:</source>
-        <translation type="unfinished"></translation>
+        <translation>段前像素数:</translation>
     </message>
     <message>
         <location filename="../src/theme_dialog.cpp" line="256"/>
         <source>Pixels Below:</source>
-        <translation type="unfinished"></translation>
+        <translation>段后像素数:</translation>
     </message>
     <message>
         <location filename="../src/theme_dialog.cpp" line="492"/>
@@ -1166,77 +1167,77 @@
 <context>
     <name>ThemeManager</name>
     <message>
-        <location filename="../src/theme_manager.cpp" line="46"/>
+        <location filename="../src/theme_manager.cpp" line="47"/>
         <source>Themes</source>
         <translation>主题</translation>
     </message>
     <message>
-        <location filename="../src/theme_manager.cpp" line="72"/>
+        <location filename="../src/theme_manager.cpp" line="73"/>
         <source>Add</source>
         <translation>添加</translation>
     </message>
     <message>
-        <location filename="../src/theme_manager.cpp" line="76"/>
+        <location filename="../src/theme_manager.cpp" line="77"/>
         <source>Modify</source>
         <translation>修改</translation>
     </message>
     <message>
-        <location filename="../src/theme_manager.cpp" line="80"/>
+        <location filename="../src/theme_manager.cpp" line="81"/>
         <source>Remove</source>
         <translation>移除</translation>
     </message>
     <message>
-        <location filename="../src/theme_manager.cpp" line="84"/>
+        <location filename="../src/theme_manager.cpp" line="85"/>
         <source>Import</source>
         <translation>导入</translation>
     </message>
     <message>
-        <location filename="../src/theme_manager.cpp" line="88"/>
+        <location filename="../src/theme_manager.cpp" line="89"/>
         <source>Export</source>
         <translation>导出</translation>
     </message>
     <message>
-        <location filename="../src/theme_manager.cpp" line="92"/>
+        <location filename="../src/theme_manager.cpp" line="93"/>
         <source>Close</source>
         <translation>关闭</translation>
     </message>
     <message>
-        <location filename="../src/theme_manager.cpp" line="182"/>
+        <location filename="../src/theme_manager.cpp" line="184"/>
         <source>Question</source>
         <translation>询问</translation>
     </message>
     <message>
-        <location filename="../src/theme_manager.cpp" line="182"/>
+        <location filename="../src/theme_manager.cpp" line="184"/>
         <source>Remove selected theme?</source>
         <translation>移除所选主题？</translation>
     </message>
     <message>
-        <location filename="../src/theme_manager.cpp" line="195"/>
+        <location filename="../src/theme_manager.cpp" line="205"/>
         <source>Import Theme</source>
         <translation>导入主题</translation>
     </message>
     <message>
-        <location filename="../src/theme_manager.cpp" line="195"/>
+        <location filename="../src/theme_manager.cpp" line="205"/>
         <source>Themes (*.fwtz *.theme)</source>
         <translation>主题 (*.fwtz *.theme)</translation>
     </message>
     <message>
-        <location filename="../src/theme_manager.cpp" line="256"/>
+        <location filename="../src/theme_manager.cpp" line="266"/>
         <source>Themes (*.fwtz)</source>
         <translation>主题 (*.fwtz)</translation>
     </message>
     <message>
-        <location filename="../src/theme_manager.cpp" line="204"/>
+        <location filename="../src/theme_manager.cpp" line="214"/>
         <source>Sorry</source>
-        <translation>Sorry</translation>
+        <translation>抱歉</translation>
     </message>
     <message>
-        <location filename="../src/theme_manager.cpp" line="204"/>
+        <location filename="../src/theme_manager.cpp" line="214"/>
         <source>A theme already exists with that name. Please enter a new name:</source>
         <translation>已经存在同名的一个主题。请输入新的名称：</translation>
     </message>
     <message>
-        <location filename="../src/theme_manager.cpp" line="256"/>
+        <location filename="../src/theme_manager.cpp" line="266"/>
         <source>Export Theme</source>
         <translation>导出主题</translation>
     </message>
@@ -1385,7 +1386,7 @@
     <message>
         <location filename="../src/rtf/tokenizer.cpp" line="151"/>
         <source>Unexpectedly reached end of file.</source>
-        <translation>Unexpectedly reached end of file.</translation>
+        <translation>意外地跳到了文件末尾.</translation>
     </message>
 </context>
 <context>
@@ -1402,93 +1403,93 @@
     </message>
     <message>
         <location filename="../src/window.cpp" line="295"/>
-        <location filename="../src/window.cpp" line="1106"/>
+        <location filename="../src/window.cpp" line="1105"/>
         <source>Untitled</source>
         <translation>无标题</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="698"/>
+        <location filename="../src/window.cpp" line="697"/>
         <source>Open File</source>
         <translation>打开文件</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="889"/>
+        <location filename="../src/window.cpp" line="888"/>
         <source>About FocusWriter</source>
         <translation>关于 FocusWriter</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="892"/>
+        <location filename="../src/window.cpp" line="891"/>
         <source>FocusWriter</source>
-        <translation type="unfinished"></translation>
+        <translation>FocusWriter</translation>
+    </message>
+    <message>
+        <location filename="../src/window.cpp" line="892"/>
+        <source>A simple fullscreen word processor</source>
+        <translation>一个简洁的全屏文字处理软件</translation>
     </message>
     <message>
         <location filename="../src/window.cpp" line="893"/>
-        <source>A simple fullscreen word processor</source>
-        <translation type="unfinished"></translation>
+        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
+        <translation>版权 &amp;copy; 2008-%1 Graeme Gott</translation>
     </message>
     <message>
         <location filename="../src/window.cpp" line="894"/>
-        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
-        <translation type="unfinished"></translation>
+        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
+        <translation>以 &lt;a href=%1&gt;GPL 3&lt;/a&gt; 许可协议发布</translation>
     </message>
     <message>
         <location filename="../src/window.cpp" line="895"/>
-        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
-        <translation type="unfinished"></translation>
+        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
+        <translation>使用 &lt;a href=%1&gt;Oxygen&lt;/a&gt; 图标主题</translation>
     </message>
     <message>
         <location filename="../src/window.cpp" line="896"/>
-        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/window.cpp" line="897"/>
         <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
-        <translation type="unfinished"></translation>
+        <translation>遵照 &lt;a href=%1&gt;LGPL 3&lt;/a&gt; 许可使用</translation>
     </message>
     <message>
         <location filename="../src/window.cpp" line="164"/>
-        <location filename="../src/window.cpp" line="952"/>
+        <location filename="../src/window.cpp" line="951"/>
         <source>Characters: %L1 / %L2</source>
         <translation>字符数：%L1 / %L2</translation>
     </message>
     <message>
         <location filename="../src/window.cpp" line="162"/>
-        <location filename="../src/window.cpp" line="953"/>
+        <location filename="../src/window.cpp" line="952"/>
         <source>Pages: %L1</source>
         <translation>页数：%L1</translation>
     </message>
     <message>
         <location filename="../src/window.cpp" line="163"/>
-        <location filename="../src/window.cpp" line="954"/>
+        <location filename="../src/window.cpp" line="953"/>
         <source>Paragraphs: %L1</source>
         <translation>段落数：%L1</translation>
     </message>
     <message>
         <location filename="../src/window.cpp" line="161"/>
-        <location filename="../src/window.cpp" line="955"/>
+        <location filename="../src/window.cpp" line="954"/>
         <source>Words: %L1</source>
         <translation>单词数：%L1</translation>
     </message>
     <message>
         <location filename="../src/window.cpp" line="165"/>
-        <location filename="../src/window.cpp" line="1017"/>
+        <location filename="../src/window.cpp" line="1016"/>
         <source>%1% of daily goal</source>
         <translation>每日目标的 %1%</translation>
     </message>
     <message>
-        <location filename="../src/document.cpp" line="447"/>
-        <location filename="../src/window.cpp" line="1057"/>
+        <location filename="../src/document.cpp" line="462"/>
+        <location filename="../src/window.cpp" line="1056"/>
         <source>Opening %1</source>
         <translation>正在打开 %1</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="1148"/>
+        <location filename="../src/window.cpp" line="1147"/>
         <source>Question</source>
         <translation>询问</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="1148"/>
+        <location filename="../src/window.cpp" line="1147"/>
         <source>Save changes?</source>
         <translation>保存更改？</translation>
     </message>
@@ -1501,32 +1502,32 @@
     <message>
         <location filename="../src/window.cpp" line="191"/>
         <source>Switch to Next Document</source>
-        <translation type="unfinished"></translation>
+        <translation>跳转到下一文档</translation>
     </message>
     <message>
         <location filename="../src/window.cpp" line="197"/>
         <source>Switch to Previous Document</source>
-        <translation type="unfinished"></translation>
+        <translation>跳转到上一文档</translation>
     </message>
     <message>
         <location filename="../src/window.cpp" line="203"/>
         <source>Switch to First Document</source>
-        <translation type="unfinished"></translation>
+        <translation>跳转到第一个文档</translation>
     </message>
     <message>
         <location filename="../src/window.cpp" line="209"/>
         <source>Switch to Last Document</source>
-        <translation type="unfinished"></translation>
+        <translation>跳转到最后一个文档</translation>
     </message>
     <message>
         <location filename="../src/window.cpp" line="217"/>
         <source>Switch to Document %1</source>
-        <translation type="unfinished"></translation>
+        <translation>跳转到文档 %1</translation>
     </message>
     <message>
         <location filename="../src/window.cpp" line="284"/>
         <source>Loading settings</source>
-        <translation>栽入设置</translation>
+        <translation>加载设置中</translation>
     </message>
     <message>
         <location filename="../src/window.cpp" line="303"/>
@@ -1535,7 +1536,7 @@
     </message>
     <message>
         <location filename="../src/window.cpp" line="359"/>
-        <location filename="../src/window.cpp" line="1071"/>
+        <location filename="../src/window.cpp" line="1070"/>
         <source>Warning</source>
         <translation>警告</translation>
     </message>
@@ -1550,27 +1551,27 @@
         <translation>从紧急缓存中还原？</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="496"/>
+        <location filename="../src/window.cpp" line="495"/>
         <source>Some files could not be opened.</source>
         <translation>有些文件无法打开。</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="499"/>
+        <location filename="../src/window.cpp" line="498"/>
         <source>Some files were opened Read-Only.</source>
         <translation>一些文件以只读方式打开。</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="698"/>
+        <location filename="../src/window.cpp" line="697"/>
         <source>Text Files (%1);;All Files (*)</source>
         <translation>文本文件 (%1);;所有文件 (*)</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="1072"/>
+        <location filename="../src/window.cpp" line="1071"/>
         <source>&apos;%1&apos; is newer than the cached copy.</source>
         <translation>&apos;%1&apos; 比缓存的副本新。</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="1073"/>
+        <location filename="../src/window.cpp" line="1072"/>
         <source>Overwrite newer file?</source>
         <translation>覆盖较新的文件？</translation>
     </message>
@@ -1582,7 +1583,7 @@
     <message>
         <location filename="../src/window.cpp" line="1174"/>
         <source>Please make sure that SDL_mixer is installed.</source>
-        <translation type="unfinished"></translation>
+        <translation>请确认 SDL_mixer 已被安装.</translation>
     </message>
     <message>
         <location filename="../src/window.cpp" line="1265"/>
@@ -1607,7 +1608,7 @@
     <message>
         <location filename="../src/window.cpp" line="1315"/>
         <source>Reloa&amp;d</source>
-        <translation type="unfinished"></translation>
+        <translation>重新载入(&amp;d)</translation>
     </message>
     <message>
         <location filename="../src/window.cpp" line="1317"/>
@@ -1692,12 +1693,12 @@
     <message>
         <location filename="../src/window.cpp" line="1352"/>
         <source>Paste &amp;Unformatted</source>
-        <translation type="unfinished"></translation>
+        <translation>无格式粘贴(&amp;U)</translation>
     </message>
     <message>
         <location filename="../src/window.cpp" line="1352"/>
         <source>Ctrl+Shift+V</source>
-        <translation type="unfinished"></translation>
+        <translation>Ctrl+Shift+V</translation>
     </message>
     <message>
         <location filename="../src/window.cpp" line="1354"/>
@@ -1707,12 +1708,12 @@
     <message>
         <location filename="../src/window.cpp" line="1355"/>
         <source>Select &amp;Scene</source>
-        <translation type="unfinished"></translation>
+        <translation>选择场景(&amp;S)</translation>
     </message>
     <message>
         <location filename="../src/window.cpp" line="1355"/>
         <source>Ctrl+Shift+A</source>
-        <translation type="unfinished"></translation>
+        <translation>Ctrl+Shift+A</translation>
     </message>
     <message>
         <location filename="../src/window.cpp" line="1358"/>
@@ -1827,12 +1828,12 @@
     <message>
         <location filename="../src/window.cpp" line="1394"/>
         <source>Le&amp;ft to Right Block</source>
-        <translation>左至右块(&amp;F)</translation>
+        <translation>从左到右(&amp;F)</translation>
     </message>
     <message>
         <location filename="../src/window.cpp" line="1396"/>
         <source>Ri&amp;ght to Left Block</source>
-        <translation>右至左块 (&amp;G)</translation>
+        <translation>从右到左 (&amp;G)</translation>
     </message>
     <message>
         <location filename="../src/window.cpp" line="1404"/>
@@ -1897,7 +1898,7 @@
     <message>
         <location filename="../src/window.cpp" line="1424"/>
         <source>S&amp;ymbols...</source>
-        <translation type="unfinished"></translation>
+        <translation>符号...(&amp;y)</translation>
     </message>
     <message>
         <location filename="../src/window.cpp" line="1427"/>
@@ -1917,7 +1918,7 @@
     <message>
         <location filename="../src/window.cpp" line="1439"/>
         <source>F&amp;ocused Text</source>
-        <translation type="unfinished"></translation>
+        <translation>聚焦文本(&amp;F)</translation>
     </message>
     <message>
         <location filename="../src/window.cpp" line="1441"/>
@@ -1957,27 +1958,27 @@
     <message>
         <location filename="../src/window.cpp" line="1458"/>
         <source>Focus Off</source>
-        <translation type="unfinished"></translation>
+        <translation>关闭聚焦</translation>
     </message>
     <message>
         <location filename="../src/window.cpp" line="1460"/>
         <source>Focus One Line</source>
-        <translation type="unfinished"></translation>
+        <translation>聚焦一行</translation>
     </message>
     <message>
         <location filename="../src/window.cpp" line="1462"/>
         <source>Focus Three Lines</source>
-        <translation type="unfinished"></translation>
+        <translation>聚焦三行</translation>
     </message>
     <message>
         <location filename="../src/window.cpp" line="1463"/>
         <source>&amp;Paragraph</source>
-        <translation type="unfinished"></translation>
+        <translation>段落(&amp;P)</translation>
     </message>
     <message>
         <location filename="../src/window.cpp" line="1464"/>
         <source>Focus Paragraph</source>
-        <translation type="unfinished"></translation>
+        <translation>聚焦段落</translation>
     </message>
     <message>
         <location filename="../src/window.cpp" line="1477"/>
@@ -1990,29 +1991,29 @@
         <translation>程序语言(&amp;L)...</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="429"/>
+        <location filename="../src/window.cpp" line="427"/>
         <source>Some files were unsupported and could not be opened.</source>
-        <translation type="unfinished"></translation>
+        <translation>某些文件不受支持，不能打开。</translation>
     </message>
     <message>
         <location filename="../src/window.cpp" line="1457"/>
         <source>&amp;Off</source>
-        <translation type="unfinished"></translation>
+        <translation>关闭(&amp;O)</translation>
     </message>
     <message>
         <location filename="../src/window.cpp" line="1459"/>
         <source>One &amp;Line</source>
-        <translation type="unfinished"></translation>
+        <translation>单行(&amp;L)</translation>
     </message>
     <message>
         <location filename="../src/window.cpp" line="1461"/>
         <source>&amp;Three Lines</source>
-        <translation type="unfinished"></translation>
+        <translation>三行(&amp;T)</translation>
     </message>
     <message>
         <location filename="../src/window.cpp" line="1478"/>
         <source>&amp;About</source>
-        <translation>关于&amp;About</translation>
+        <translation>关于(&amp;A)</translation>
     </message>
     <message>
         <location filename="../src/window.cpp" line="1486"/>
